# ../rpg4go/Command.py

# =============================================================================
# >> IMPORTS
# =============================================================================
import rpg4go.globals


# =============================================================================
# >> CLASS: Command
# =============================================================================
class Command:
    '''Instances hold name(s) and action, which will be activated when the
instance is called by one of it's names.'''

    # ===========
    # > Generic
    # ===========
    def __init__(self, names, action, minArgs=0, maxArgs=0):
        '''Create new instance of Command.'''

        # Was there only one name given for the command?
        if type(names) == str:

            # Save the name as a list
            self.names = [names]

        # Were there multiple names?
        elif type(names) == list:

            # Save all the names
            self.names = names

        # Save action as attribute
        self.action = action

        # Save minArgs attribute
        self.minArgs = minArgs

        # Is maxArgs smaller than minArgs?
        if maxArgs < minArgs:

            # Set maxArgs attribute to match minArgs
            self.maxArgs = minArgs

        # Is it greater or as great as minArgs?
        else:

            # Save maxArgs attribute
            self.maxArgs = maxArgs

        # Add command to command list
        rpg4go.globals.addCommand(self)

    def activate(self, user, args):
        '''Call command's action with given arguments.'''

        # Were there too many or too little arguments given?
        if len(args) > self.maxArgs or len(args) < self.minArgs:

            # Is minArgs equal to maxArgs?
            if self.minArgs == self.maxArgs:

                # Message user
                user.message("%i arguments given instead of expected %i."
                    %(len(args), self.minArgs))

            # If minArgs is not equal to maxArgs
            else:

                # Message user
                user.message("%i arguments given instead of expected %i-%i."
                    %(len(args), self.minArgs, self.maxArgs))

        # Allowed number of arguments
        else:

            # Call command's action with arguments
            self.action(user, *args)
