# ../gorpg/commands.py

# =============================================================================
# >> IMPORTS
# =============================================================================
from rpg4go.Command import Command
import rpg4go.config
import rpg4go.globals


# =============================================================================
# >> COMMAND FUNCTIONS
# =============================================================================
def showHelp(user):
    '''Show help for using rpg4go in-game.'''

    # Create a string for storing command names
    names = ""
    
    # Loop through all the commands
    for cmd in rpg4go.globals.command_list:

        # Loop through the command's names
        for name in cmd.names:

            # Save the name to names string
            names += "%s%s; " %(rpg4go.config.prefix, name)

        # Change last ", " to '\n'
        names = names[:-2] + '\n'

    # Message user
    user.message("rpg4go version %s commands:\n%s" %(rpg4go.globals.version, names.strip())) # remove last '\n'

def addSkillPoint(user, skill):
    '''Decrease user's skill points to level up a skill.'''

    # Loop through all user's skills
    for s in user.skills:

        # See if this skill is the skill user is trying to level up
        if skill.lower() == s.__class__.__name__.lower():

            # Is the skill at it's maximum level?
            if s.level >= s.__class__.maxLevel:

                # Message user
                user.message("'%s' is already at maximum level." %s.__class__.__name__)

            # If it's not at it's maximum level
            else:
            
                # Does user have enough skill points? (reminder for Mahi: level 0)
                if user.skillPoints > s.level:

                    # Level up the skill and remove skill point(s) from user
                    s.level += 1
                    user.skillPoints -= s.level

                    # Message user
                    user.message("'%s' is now at level %i." %(s.__class__.__name__, s.level))

                # If user didn't have enough skill points
                else:
                
                    # Message user
                    user.message("You don't have the requireed %i skill points." %(s.level + 1))

            # Exit
            return

    # Message user if skill was not found
    user.message("Unknown skill '%s'." %skill)

def removeSkillPoint(user, skill):
    '''Level down a skill to increase user's skill points.'''

    # Loop through all user's skills
    for s in user.skills:
        
        # See if this skill is the skill user is trying to level down
        if skill.lower() == s.__class__.__name__.lower():

            # Does the skill have levels to be taken?
            if s.level > 0:
            
                # Level down the skill and add half of the skill point(s) to user
                user.skillPoints += round(s.level / 2)
                s.level -= 1

                # Message user
                user.message("'%s' is now at level %i" %(s.__class__.__name__, s.level))

            # If skill didn't have enough levels
            else:

                # Message user
                user.message("Skill is only at level %i." %s.level)

            # Exit
            return

    # Message user if skill was not found
    user.message("Unknown skill '%s'." %skill)

def showUserInfo(user, target=None):
    '''Show targer's (user if None) gorpg information.'''

    # Was target given?
    if target:

        # Loop through all the active users on the server
        for u in rpg4go.globals.user_list:

            # Does user's name match target's name?
            if target.lower() in u.player.GetName().lower():

                # Message user target's info
                user.message("Level: %i - Exp: %i/%i - Skill points: %i"
                             %(u.level, u.exp, u.getRequiredExp(), u.skillPoints))

                # Exit
                return

        # Message user if target was not found
        user.message("Unknown user '%s'." %target)

    # If no target was given
    else:

        # Message user his own info
        user.message("Level: %i - Exp: %i/%i - Skill points: %i"
                     %(user.level, user.exp, user.getRequiredExp(), user.skillPoints))

def showSkillInfo(user, target=None):
    '''Show info for the target skill, or list all available skills if target is None.'''

    # Was skill given?
    if target:

        # Loop through all the skills
        for skill in rpg4go.globals.skill_list:

            # Is this skill the skill user is trying to get info of?
            if target.lower() == skill.__name__.lower():

                # Message user skill's info
                user.message("%s (maxlvl %i): %s" %(skill.__name__, skill.maxLevel, skill.description))

                # Exit
                return

        # Message user if skill wasn't found
        user.message("Unable to find skill '%s', type '%sskillinfo' for list of skills" %(target, rpg4go.config.prefix))

    # If target skill was not given
    else:

        # Create a string for storing skill names
        skills = ""

        # Loop through all the skills
        for skill in rpg4go.globals.skill_list:

            # Save skill's name
            skills += "%s, " %skill.__name__

        # Message skill names list to user
        user.message("usage: '%sskillinfo <skill>'\nskills: %s" %(rpg4go.config.prefix, skills[:-2])) #remove last ", "
    

# =============================================================================
# >> COMMAND INITIALIZATION
# =============================================================================
def initCommands():
    Command(["rpg4go", "help"], showHelp)
    Command(["addskillpoint", "skill+"], addSkillPoint, 1)
    Command(["removeskillpoint", "skill-"], removeSkillPoint, 1)
    Command("userinfo", showUserInfo, 0, 1)
    Command("skillinfo", showSkillInfo, 0, 1)
