# ../rpg4go/rpg4go.py

# =============================================================================
# >> IMPORTS
# =============================================================================
from rpg4go.User import User
from rpg4go.skills import initSkills
from rpg4go.commands import initCommands
import rpg4go.config
import rpg4go.globals

# Python
import sqlite3

# Source.Python
from events import Event


# =============================================================================
# >> SETUP
# =============================================================================
# Initialize global lists
rpg4go.globals.initLists()
initCommands()
initSkills()

# Register sqlite3 User functions
sqlite3.register_adapter(User, User.adapt)
sqlite3.register_converter("user", User.convert)

# Connect to database
conn = sqlite3.connect(rpg4go.config.database)
cur = conn.cursor()

# Make sure users table exists
cur.execute("CREATE TABLE IF NOT EXISTS users (steamid TEXT PRIMARY KEY, user User)")

# Save and close connection
cur.close()
conn.commit()
conn.close()


# =============================================================================
# >> EVENTS
# =============================================================================
@Event
def player_spawn(e):

    # Get user's userid
    userid = e.GetInt("userid")

    # Try receiving user from user_list
    user = User.getUser(userid)

    # Was user not active?
    if not user:
        # Create a new User object
        user = User.new(userid)

        # Loading possible user's data from database
        user.loadFromDatabase()

        # Activate user
        user.activate()

        # Welcome user to server
        user.message("This server is using Mahi's rpg4go v%s, type %srpg4go for help." %(rpg4go.globals.version, rpg4go.config.prefix))

    # Message user's gorpg info
    user.message("Level: %i - Exp: %i/%i - Skill points: %i"
                 %(user.level, user.exp, user.getRequiredExp(), user.skillPoints))
    
    # Activate player_spawn skills for user
    user.activateSkills("player_spawn")

@Event
def player_disconnect(e):

    # Get user's userid
    userid = e.GetInt("userid")

    # Get user from user_list
    user = User.getUser(userid)

    # Release user from user_list
    user.release()

    # Save user's data to databse
    user.saveToDatabase()

@Event
def player_death(e):

    # Receive users for victim and attacker
    victim = User.getUser(e.GetInt("userid"))
    attacker = User.getUser(e.GetInt("attacker"))

    # If victim is not an ally of attacker
    if victim.player.GetTeamIndex() != attacker.player.GetTeamIndex():

        # Add exp for attacker
        attacker.addExp(rpg4go.config.exp_gain["kill"])

    # Activate player_kill skills for attacker
    attacker.activateSkills("player_kill", victim)

    # Activate player_deaths skills for victim
    victim.activateSkills("player_death")

@Event
def player_say(e):

    # Get user from user_list
    user = User.getUser(e.GetInt("userid"))

    # Get said text
    text = e.GetString("text")

    # Does text begin with rpg4go prefix?
    if text.startswith(rpg4go.config.prefix):

        # Split words into list items
        text = text.split(" ")

        # Loop through all commands in command_list
        for cmd in rpg4go.globals.command_list:

            # See if text equals to command's name
            if text[0][len(rpg4go.config.prefix):] in cmd.names:

                # Activate command
                cmd.activate(user, text[1:])

                # Exit
                return
